@@ -2,7 +2,7 @@ from typing_extensions import override
 
 from juham_automation import JApp
 from juham_automation import PowerMeterSimulator
-from juham_automation import HotWaterOptimizer
+from juham_automation import HeatingOptimizer
 
 
 class MyApp(JApp):
@@ -20,7 +20,7 @@ class MyApp(JApp):
         self.add(PowerMeterSimulator("powerconsumption"))
 
         # Heating plan for the main boiler, with shelly's temperature sensor
-        self.add(HotWaterOptimizer("boiler", "temperature/102", 0, 3, 0.15))
+        self.add(HeatingOptimizer("boiler", "temperature/102", 0, 3, 0.15))
 
         # print the instance hierarchy
         self.print()
