@@ -10,7 +10,8 @@ from .automation import EnergyCostCalculator
 from .automation import PowerMeterSimulator
 from .automation import SpotHintaFi
 from .automation import WaterCirculator
-from .automation import HotWaterOptimizer
+from .automation import HeatingOptimizer
+from .automation import EnergyBalancer
 from .ts import EnergyCostCalculatorTs
 from .ts import ForecastTs
 from .ts import LogTs
@@ -18,6 +19,7 @@ from .ts import PowerTs
 from .ts import PowerPlanTs
 from .ts import PowerMeterTs
 from .ts import ElectricityPriceTs
+from .ts import EnergyBalancerTs
 from .japp import JApp
 
 
@@ -25,7 +27,8 @@ __all__ = [
     "EnergyCostCalculator",
     "EnergyCostCalculatorTs",
     "ForecastTs",
-    "HotWaterOptimizer",
+    "HeatingOptimizer",
+    "EnergyBalancer",
     "LogTs",
     "PowerTs",
     "PowerPlanTs",
@@ -35,4 +38,5 @@ __all__ = [
     "JApp",
     "PowerMeterSimulator",
     "ElectricityPriceTs",
+    "EnergyBalancerTs",
 ]
