@@ -9,13 +9,15 @@ Juham - Juha's Ultimate Home Automation classes
 from .energycostcalculator import EnergyCostCalculator
 from .spothintafi import SpotHintaFi
 from .watercirculator import WaterCirculator
-from .hotwateroptimizer import HotWaterOptimizer
+from .heatingoptimizer import HeatingOptimizer
+from .energybalancer import EnergyBalancer
 from .powermeter_simulator import PowerMeterSimulator
 
 __all__ = [
     "EnergyCostCalculator",
-    "HotWaterOptimizer",
+    "HeatingOptimizer",
     "SpotHintaFi",
     "WaterCirculator",
     "PowerMeterSimulator",
+    "EnergyBalancer",
 ]
