@@ -1,3 +1,4 @@
+from juham_automation.automation.energybalancer import EnergyBalancer
 from masterpiece import Application
 from juham_core import Juham
 
@@ -5,6 +6,7 @@ from .ts import ForecastTs
 from .ts import PowerTs
 from .ts import PowerPlanTs
 from .ts import PowerMeterTs
+from .ts import EnergyBalancerTs
 from .ts import LogTs
 from .ts import EnergyCostCalculatorTs
 from .ts import ElectricityPriceTs
@@ -42,6 +44,8 @@ class JApp(Application):
         self.add(EnergyCostCalculator())
         self.add(EnergyCostCalculatorTs())
         self.add(ElectricityPriceTs())
+        self.add(EnergyBalancer())
+        self.add(EnergyBalancerTs())
 
     @classmethod
     def register(cls) -> None:
