@@ -2,7 +2,7 @@
 Description
 ===========
 
-Juham - Juha's Ultimate Home Automation Timeseries 
+Time series recorders for Juha's Ultimate Home Automation classes.
 
 """
 
@@ -13,6 +13,7 @@ from .powerplan_ts import PowerPlanTs
 from .powermeter_ts import PowerMeterTs
 from .electricityprice_ts import ElectricityPriceTs
 from .forecast_ts import ForecastTs
+from .energybalancer_ts import EnergyBalancerTs
 
 __all__ = [
     "EnergyCostCalculatorTs",
@@ -22,4 +23,5 @@ __all__ = [
     "PowerPlanTs",
     "PowerMeterTs",
     "ElectricityPriceTs",
+    "EnergyBalancerTs",
 ]
