@@ -31,6 +31,9 @@ class PowerPlanTs(JuhamTs):
         uoi = m["UOI"]
         ts = m["Timestamp"]
 
+        tempForecast : float = float(m.get("TempForecast", 0.0))
+        solarForecast : float = float(m.get("SolarForecast", 0.0))
+
         point = (
             self.measurement("powerplan")
             .tag("unit", m["Unit"])
@@ -40,6 +43,8 @@ class PowerPlanTs(JuhamTs):
             .field("power", 16.0)  # kW
             .field("Schedule", schedule)  # figures of merit
             .field("UOI", float(uoi))  # Utilitzation Optimizing Index
+            .field("TempForecast", tempForecast)  # next day temp forecast
+            .field("SolarForecast", solarForecast) # next day solar forecast
             .time(epoc2utc(ts))
         )
         self.write(point)
